@@ -4,4 +4,4 @@ use proc_macro2::TokenStream;
 pub mod client;
 pub mod model;
 pub mod util;
-mod template;
\ No newline at end of file
+pub mod format;
